🌐 Server Stats
============================================

Server Interface
------------------
.. automodule:: novauniverse.interfaces.stats.server
   :members:
   :undoc-members:
   :show-inheritance:


ServerInfo Reference
--------------------------------------------------------
.. automodule:: novauniverse.interfaces.stats.server.server_info
   :members:
   :undoc-members:
   :show-inheritance:

Global Reference
----------------------------------------------------
.. automodule:: novauniverse.interfaces.stats.server.global_
   :members:
   :undoc-members:
   :show-inheritance:

NovaOnlinePlayer Reference
----------------------------------------------------------------
.. automodule:: novauniverse.interfaces.stats.server.nova_online_player
   :members:
   :undoc-members:
   :show-inheritance:

NovaServer Reference
--------------------------------------------------------
.. automodule:: novauniverse.interfaces.stats.server.nova_server
   :members:
   :undoc-members:
   :show-inheritance:

PlayerPreview Reference
-----------------------------------------------------------
.. automodule:: novauniverse.interfaces.stats.server.player_preview
   :members:
   :undoc-members:
   :show-inheritance:

System Reference
--------------------------------------------------
.. automodule:: novauniverse.interfaces.stats.server.system
   :members:
   :undoc-members:
   :show-inheritance: